@@ -3,13 +3,8 @@ import typing
 import bpy_types
 import bpy_extras.object_utils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
-    align_items = None
-    ''' '''
-
     bl_idname = None
     ''' '''
 
@@ -85,6 +80,24 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def invoke(self, context, _event):
         ''' 
 
@@ -163,6 +176,12 @@ class AddTorus(bpy_types.Operator, bpy_extras.object_utils.AddObjectHelper):
         '''
         pass
 
+    def poll_message_set(self):
+        ''' 
+
+        '''
+        pass
+
     def pop(self):
         ''' 
 
