@@ -2,74 +2,279 @@ import sys
 import typing
 import bpy_types
 
-from . import properties_data_metaball
-from . import properties_scene
-from . import properties_grease_pencil_common
-from . import properties_view_layer
-from . import space_graph
-from . import properties_physics_softbody
-from . import properties_data_volume
-from . import properties_freestyle
-from . import space_console
-from . import properties_physics_field
-from . import properties_particle
-from . import properties_data_hair
-from . import properties_physics_fluid
-from . import space_properties
-from . import properties_collection
-from . import properties_data_pointcloud
-from . import properties_world
-from . import space_node
-from . import properties_data_light
-from . import properties_paint_common
-from . import space_sequencer
-from . import space_text
 from . import properties_data_curve
-from . import properties_constraint
-from . import space_view3d
-from . import properties_data_empty
-from . import properties_physics_rigidbody
-from . import properties_physics_dynamicpaint
-from . import space_userpref
-from . import properties_data_lattice
-from . import space_topbar
-from . import space_nla
-from . import properties_physics_cloth
-from . import properties_physics_common
-from . import properties_data_lightprobe
-from . import utils
-from . import space_spreadsheet
-from . import space_outliner
-from . import space_toolsystem_toolbar
-from . import properties_material
-from . import space_toolsystem_common
 from . import properties_render
-from . import properties_data_gpencil
-from . import space_dopesheet
-from . import space_view3d_toolbar
+from . import properties_data_lattice
+from . import properties_data_hair
 from . import properties_workspace
-from . import properties_data_shaderfx
-from . import space_time
-from . import properties_physics_rigidbody_constraint
-from . import space_filebrowser
-from . import properties_data_modifier
-from . import space_info
-from . import space_statusbar
-from . import properties_output
-from . import properties_texture
-from . import properties_animviz
-from . import space_image
-from . import space_clip
+from . import space_outliner
+from . import properties_grease_pencil_common
 from . import properties_data_mesh
-from . import properties_material_gpencil
-from . import properties_mask_common
-from . import properties_object
-from . import properties_data_speaker
-from . import properties_data_camera
+from . import properties_physics_softbody
+from . import properties_particle
+from . import properties_data_pointcloud
+from . import properties_physics_common
 from . import properties_data_bone
+from . import space_graph
+from . import properties_scene
+from . import space_info
+from . import space_text
+from . import space_sequencer
+from . import properties_data_shaderfx
+from . import properties_data_gpencil
 from . import properties_data_armature
+from . import space_toolsystem_common
+from . import properties_world
+from . import properties_constraint
+from . import properties_data_metaball
+from . import properties_data_modifier
+from . import space_node
+from . import space_view3d_toolbar
+from . import properties_physics_rigidbody_constraint
+from . import space_toolsystem_toolbar
+from . import space_nla
+from . import properties_freestyle
+from . import properties_data_volume
+from . import utils
+from . import space_image
+from . import properties_data_lightprobe
+from . import properties_physics_rigidbody
+from . import properties_paint_common
+from . import properties_material
+from . import properties_data_camera
+from . import properties_physics_field
+from . import properties_object
+from . import space_spreadsheet
+from . import properties_data_speaker
+from . import space_console
+from . import space_dopesheet
+from . import properties_data_light
+from . import space_clip
+from . import space_topbar
+from . import space_filebrowser
+from . import properties_collection
+from . import space_statusbar
+from . import properties_mask_common
+from . import space_time
+from . import properties_material_gpencil
+from . import properties_physics_dynamicpaint
+from . import properties_data_empty
+from . import space_view3d
+from . import properties_texture
+from . import properties_output
+from . import properties_physics_cloth
+from . import space_properties
+from . import properties_animviz
+from . import properties_physics_fluid
+from . import space_userpref
+from . import properties_view_layer
 
-GenericType = typing.TypeVar("GenericType")
+
+class UI_MT_list_item_context_menu(bpy_types.Menu, bpy_types._GenericUI):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
 
 
 class UI_UL_list(bpy_types.UIList, bpy_types._GenericUI):
@@ -128,6 +333,24 @@ class UI_UL_list(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
