@@ -3,8 +3,6 @@ import typing
 import bpy_types
 import rna_prop_ui
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class WorkSpaceButtonsPanel:
     bl_category = None
@@ -94,6 +92,24 @@ class WORKSPACE_PT_addons(WorkSpaceButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -281,6 +297,24 @@ class WORKSPACE_PT_custom_props(WorkSpaceButtonsPanel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
@@ -467,6 +501,24 @@ class WORKSPACE_PT_main(WorkSpaceButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
