@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ToolActivePanelHelper:
     bl_label = None
@@ -47,9 +45,15 @@ class ToolDef:
     operator = None
     ''' '''
 
+    options = None
+    ''' '''
+
     widget = None
     ''' '''
 
+    widget_properties = None
+    ''' '''
+
     def count(self, value):
         ''' 
 
@@ -89,7 +93,7 @@ class ToolSelectPanelHelper:
         '''
         pass
 
-    def draw_active_tool_header(self, context, layout, show_tool_name,
+    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                 tool_key):
         ''' 
 
@@ -132,6 +136,18 @@ class ToolSelectPanelHelper:
         '''
         pass
 
+    def tools_all(self):
+        ''' 
+
+        '''
+        pass
+
+    def tools_from_context(self, context, mode):
+        ''' 
+
+        '''
+        pass
+
 
 class WM_MT_toolsystem_submenu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
@@ -203,6 +219,24 @@ class WM_MT_toolsystem_submenu(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
     def is_extended(self):
         ''' 
 
