@@ -10,7 +10,7 @@ def assign_action():
     pass
 
 
-def bundle_install(asset_library_ref: typing.Union[int, str] = '',
+def bundle_install(asset_library_ref: typing.Union[str, int] = '',
                    filepath: str = "",
                    hide_props_region: bool = True,
                    check_existing: bool = True,
@@ -31,12 +31,12 @@ def bundle_install(asset_library_ref: typing.Union[int, str] = '',
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
-                   display_type: typing.Union[int, str] = 'DEFAULT',
-                   sort_method: typing.Union[int, str] = ''):
+                   display_type: typing.Union[str, int] = 'DEFAULT',
+                   sort_method: typing.Union[str, int] = ''):
     ''' Copy the current .blend file into an Asset Library. Only works on standalone .blend files (i.e. when no other files are referenced)
 
     :param asset_library_ref: asset_library_ref
-    :type asset_library_ref: typing.Union[int, str]
+    :type asset_library_ref: typing.Union[str, int]
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -78,9 +78,9 @@ def bundle_install(asset_library_ref: typing.Union[int, str] = '',
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
