@@ -100,7 +100,7 @@ def change_frame(frame: int = 0):
 
 def clean_tracks(frames: int = 0,
                  error: float = 0.0,
-                 action: typing.Union[int, str] = 'SELECT'):
+                 action: typing.Union[str, int] = 'SELECT'):
     ''' Clean tracks with high error values or few frames
 
     :param frames: Tracked Frames, Effect on tracks which are tracked less than specified amount of frames
@@ -108,7 +108,7 @@ def clean_tracks(frames: int = 0,
     :param error: Reprojection Error, Effect on tracks which have got larger reprojection error
     :type error: float
     :param action: Action, Cleanup action to execute * SELECT Select -- Select unclean tracks. * DELETE_TRACK Delete Track -- Delete unclean tracks. * DELETE_SEGMENTS Delete Segments -- Delete unclean segments of tracks.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -122,12 +122,12 @@ def clear_solution():
     pass
 
 
-def clear_track_path(action: typing.Union[int, str] = 'REMAINED',
+def clear_track_path(action: typing.Union[str, int] = 'REMAINED',
                      clear_active: bool = False):
     ''' Clear tracks after/before current position or clear the whole track
 
     :param action: Action, Clear action to execute * UPTO Clear Up To -- Clear path up to current frame. * REMAINED Clear Remained -- Clear path at remaining frames (after current). * ALL Clear All -- Clear the whole path.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     :param clear_active: Clear Active, Clear active track only instead of all selected tracks
     :type clear_active: bool
     '''
@@ -193,14 +193,14 @@ def delete_track():
     pass
 
 
-def detect_features(placement: typing.Union[int, str] = 'FRAME',
+def detect_features(placement: typing.Union[str, int] = 'FRAME',
                     margin: int = 16,
                     threshold: float = 0.5,
                     min_distance: int = 120):
     ''' Automatically detect features and place markers to track
 
     :param placement: Placement, Placement for detected features * FRAME Whole Frame -- Place markers across the whole frame. * INSIDE_GPENCIL Inside Annotated Area -- Place markers only inside areas outlined with the Annotation tool. * OUTSIDE_GPENCIL Outside Annotated Area -- Place markers only outside areas outlined with the Annotation tool.
-    :type placement: typing.Union[int, str]
+    :type placement: typing.Union[str, int]
     :param margin: Margin, Only features further than margin pixels from the image edges are considered
     :type margin: int
     :param threshold: Threshold, Threshold level to consider feature good enough for tracking
@@ -212,11 +212,11 @@ def detect_features(placement: typing.Union[int, str] = 'FRAME',
     pass
 
 
-def disable_markers(action: typing.Union[int, str] = 'DISABLE'):
+def disable_markers(action: typing.Union[str, int] = 'DISABLE'):
     ''' Disable/enable selected markers
 
     :param action: Action, Disable action to execute * DISABLE Disable -- Disable selected markers. * ENABLE Enable -- Enable selected markers. * TOGGLE Toggle -- Toggle disabled flag for selected markers.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -253,11 +253,11 @@ def filter_tracks(track_threshold: float = 5.0):
     pass
 
 
-def frame_jump(position: typing.Union[int, str] = 'PATHSTART'):
+def frame_jump(position: typing.Union[str, int] = 'PATHSTART'):
     ''' Jump to special frame
 
     :param position: Position, Position to jump to * PATHSTART Path Start -- Jump to start of current path. * PATHEND Path End -- Jump to end of current path. * FAILEDPREV Previous Failed -- Jump to previous failed frame. * FAILNEXT Next Failed -- Jump to next failed frame.
-    :type position: typing.Union[int, str]
+    :type position: typing.Union[str, int]
     '''
 
     pass
@@ -287,11 +287,11 @@ def graph_delete_knot():
     pass
 
 
-def graph_disable_markers(action: typing.Union[int, str] = 'DISABLE'):
+def graph_disable_markers(action: typing.Union[str, int] = 'DISABLE'):
     ''' Disable/enable selected markers
 
     :param action: Action, Disable action to execute * DISABLE Disable -- Disable selected markers. * ENABLE Enable -- Enable selected markers. * TOGGLE Toggle -- Toggle disabled flag for selected markers.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -310,11 +310,11 @@ def graph_select(location: typing.List[float] = (0.0, 0.0),
     pass
 
 
-def graph_select_all_markers(action: typing.Union[int, str] = 'TOGGLE'):
+def graph_select_all_markers(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all markers of active track
 
     :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -406,21 +406,21 @@ def lock_selection_toggle():
     pass
 
 
-def lock_tracks(action: typing.Union[int, str] = 'LOCK'):
+def lock_tracks(action: typing.Union[str, int] = 'LOCK'):
     ''' Lock/unlock selected tracks
 
     :param action: Action, Lock action to execute * LOCK Lock -- Lock selected tracks. * UNLOCK Unlock -- Unlock selected tracks. * TOGGLE Toggle -- Toggle locked flag for selected tracks.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
 
 
-def mode_set(mode: typing.Union[int, str] = 'TRACKING'):
+def mode_set(mode: typing.Union[str, int] = 'TRACKING'):
     ''' Set the clip interaction mode
 
     :param mode: Mode * TRACKING Tracking -- Show tracking and solving tools. * MASK Mask -- Show mask editing tools.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -452,8 +452,8 @@ def open(directory: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: typing.Union[int, str] = 'DEFAULT',
-         sort_method: typing.Union[int, str] = ''):
+         display_type: typing.Union[str, int] = 'DEFAULT',
+         sort_method: typing.Union[str, int] = ''):
     ''' Load a sequence of frames or a movie file
 
     :param directory: Directory, Directory of the file
@@ -503,9 +503,9 @@ def open(directory: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -569,11 +569,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all tracking markers
 
     :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -584,7 +584,7 @@ def select_box(xmin: int = 0,
                ymin: int = 0,
                ymax: int = 0,
                wait_for_input: bool = True,
-               mode: typing.Union[int, str] = 'SET'):
+               mode: typing.Union[str, int] = 'SET'):
     ''' Select markers using box selection
 
     :param xmin: X Min
@@ -598,7 +598,7 @@ def select_box(xmin: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -608,7 +608,7 @@ def select_circle(x: int = 0,
                   y: int = 0,
                   radius: int = 25,
                   wait_for_input: bool = True,
-                  mode: typing.Union[int, str] = 'SET'):
+                  mode: typing.Union[str, int] = 'SET'):
     ''' Select markers using circle selection
 
     :param x: X
@@ -620,17 +620,17 @@ def select_circle(x: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def select_grouped(group: typing.Union[int, str] = 'ESTIMATED'):
+def select_grouped(group: typing.Union[str, int] = 'ESTIMATED'):
     ''' Select all tracks from specified group
 
     :param group: Action, Clear action to execute * KEYFRAMED Keyframed Tracks -- Select all keyframed tracks. * ESTIMATED Estimated Tracks -- Select all estimated tracks. * TRACKED Tracked Tracks -- Select all tracked tracks. * LOCKED Locked Tracks -- Select all locked tracks. * DISABLED Disabled Tracks -- Select all disabled tracks. * COLOR Tracks with Same Color -- Select all tracks with same color as active track. * FAILED Failed Tracks -- Select all tracks which failed to be reconstructed.
-    :type group: typing.Union[int, str]
+    :type group: typing.Union[str, int]
     '''
 
     pass
@@ -639,13 +639,13 @@ def select_grouped(group: typing.Union[int, str] = 'ESTIMATED'):
 def select_lasso(path: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
         List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'SET'):
+                 mode: typing.Union[str, int] = 'SET'):
     ''' Select markers using lasso selection
 
     :param path: Path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -659,11 +659,11 @@ def set_active_clip():
     pass
 
 
-def set_axis(axis: typing.Union[int, str] = 'X'):
+def set_axis(axis: typing.Union[str, int] = 'X'):
     ''' Set direction of scene axis rotating camera (or its parent if present) and assume selected track lies on real axis, joining it with the origin
 
     :param axis: Axis, Axis to use to align bundle along * X X -- Align bundle align X axis. * Y Y -- Align bundle align Y axis.
-    :type axis: typing.Union[int, str]
+    :type axis: typing.Union[str, int]
     '''
 
     pass
@@ -687,11 +687,11 @@ def set_origin(use_median: bool = False):
     pass
 
 
-def set_plane(plane: typing.Union[int, str] = 'FLOOR'):
+def set_plane(plane: typing.Union[str, int] = 'FLOOR'):
     ''' Set plane based on 3 selected bundles by moving camera (or its parent if present) in 3D space
 
     :param plane: Plane, Plane to be used for orientation * FLOOR Floor -- Set floor plane. * WALL Wall -- Set wall plane.
-    :type plane: typing.Union[int, str]
+    :type plane: typing.Union[str, int]
     '''
 
     pass
@@ -725,11 +725,11 @@ def set_solution_scale(distance: float = 0.0):
     pass
 
 
-def set_solver_keyframe(keyframe: typing.Union[int, str] = 'KEYFRAME_A'):
+def set_solver_keyframe(keyframe: typing.Union[str, int] = 'KEYFRAME_A'):
     ''' Set keyframe used by solver
 
     :param keyframe: Keyframe, Keyframe to set
-    :type keyframe: typing.Union[int, str]
+    :type keyframe: typing.Union[str, int]
     '''
 
     pass
