@@ -11,14 +11,14 @@ def add_target():
 
 
 def apply(constraint: str = "",
-          owner: typing.Union[int, str] = 'OBJECT',
+          owner: typing.Union[str, int] = 'OBJECT',
           report: bool = False):
     ''' Apply constraint and remove from the stack
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     :param report: Report, Create a notification after the operation
     :type report: bool
     '''
@@ -27,40 +27,40 @@ def apply(constraint: str = "",
 
 
 def childof_clear_inverse(constraint: str = "",
-                          owner: typing.Union[int, str] = 'OBJECT'):
+                          owner: typing.Union[str, int] = 'OBJECT'):
     ''' Clear inverse correction for Child Of constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
 def childof_set_inverse(constraint: str = "",
-                        owner: typing.Union[int, str] = 'OBJECT'):
+                        owner: typing.Union[str, int] = 'OBJECT'):
     ''' Set inverse correction for Child Of constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
 def copy(constraint: str = "",
-         owner: typing.Union[int, str] = 'OBJECT',
+         owner: typing.Union[str, int] = 'OBJECT',
          report: bool = False):
     ''' Duplicate constraint at the same position in the stack
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     :param report: Report, Create a notification after the operation
     :type report: bool
     '''
@@ -69,27 +69,27 @@ def copy(constraint: str = "",
 
 
 def copy_to_selected(constraint: str = "",
-                     owner: typing.Union[int, str] = 'OBJECT'):
+                     owner: typing.Union[str, int] = 'OBJECT'):
     ''' Copy constraint to other selected objects/bones
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
 def delete(constraint: str = "",
-           owner: typing.Union[int, str] = 'OBJECT',
+           owner: typing.Union[str, int] = 'OBJECT',
            report: bool = False):
     ''' Remove constraint from constraint stack
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     :param report: Report, Create a notification after the operation
     :type report: bool
     '''
@@ -106,7 +106,7 @@ def disable_keep_transform():
 
 
 def followpath_path_animate(constraint: str = "",
-                            owner: typing.Union[int, str] = 'OBJECT',
+                            owner: typing.Union[str, int] = 'OBJECT',
                             frame_start: int = 1,
                             length: int = 100):
     ''' Add default animation for path used by constraint if it isn't animated already
@@ -114,7 +114,7 @@ def followpath_path_animate(constraint: str = "",
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     :param frame_start: Start Frame, First frame of path animation
     :type frame_start: int
     :param length: Length, Number of frames that path animation should take
@@ -125,39 +125,39 @@ def followpath_path_animate(constraint: str = "",
 
 
 def limitdistance_reset(constraint: str = "",
-                        owner: typing.Union[int, str] = 'OBJECT'):
+                        owner: typing.Union[str, int] = 'OBJECT'):
     ''' Reset limiting distance for Limit Distance Constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
-def move_down(constraint: str = "", owner: typing.Union[int, str] = 'OBJECT'):
+def move_down(constraint: str = "", owner: typing.Union[str, int] = 'OBJECT'):
     ''' Move constraint down in constraint stack
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
 def move_to_index(constraint: str = "",
-                  owner: typing.Union[int, str] = 'OBJECT',
+                  owner: typing.Union[str, int] = 'OBJECT',
                   index: int = 0):
     ''' Change the constraint's position in the list so it evaluates after the set number of others
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     :param index: Index, The index to move the constraint to
     :type index: int
     '''
@@ -165,13 +165,13 @@ def move_to_index(constraint: str = "",
     pass
 
 
-def move_up(constraint: str = "", owner: typing.Union[int, str] = 'OBJECT'):
+def move_up(constraint: str = "", owner: typing.Union[str, int] = 'OBJECT'):
     ''' Move constraint up in constraint stack
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
@@ -186,26 +186,26 @@ def normalize_target_weights():
 
 
 def objectsolver_clear_inverse(constraint: str = "",
-                               owner: typing.Union[int, str] = 'OBJECT'):
+                               owner: typing.Union[str, int] = 'OBJECT'):
     ''' Clear inverse correction for Object Solver constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
 
 
 def objectsolver_set_inverse(constraint: str = "",
-                             owner: typing.Union[int, str] = 'OBJECT'):
+                             owner: typing.Union[str, int] = 'OBJECT'):
     ''' Set inverse correction for Object Solver constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
@@ -222,13 +222,13 @@ def remove_target(index: int = 0):
 
 
 def stretchto_reset(constraint: str = "",
-                    owner: typing.Union[int, str] = 'OBJECT'):
+                    owner: typing.Union[str, int] = 'OBJECT'):
     ''' Reset original length of bone for Stretch To Constraint
 
     :param constraint: Constraint, Name of the constraint to edit
     :type constraint: str
     :param owner: Owner, The owner of this constraint * OBJECT Object -- Edit a constraint on the active object. * BONE Bone -- Edit a constraint on the active bone.
-    :type owner: typing.Union[int, str]
+    :type owner: typing.Union[str, int]
     '''
 
     pass
