@@ -6,14 +6,14 @@ import bpy.types
 def brush_stroke(stroke: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
         List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'NORMAL',
+                 mode: typing.Union[str, int] = 'NORMAL',
                  ignore_background_click: bool = False):
     ''' Sculpt a stroke into the geometry
 
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Regular -- Apply brush normally. * INVERT Invert -- Invert action of brush for duration of stroke. * SMOOTH Smooth -- Switch brush to smooth mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param ignore_background_click: Ignore Background Click, Clicks on the background do not start the stroke
     :type ignore_background_click: bool
     '''
@@ -21,12 +21,12 @@ def brush_stroke(stroke: typing.Union[
     pass
 
 
-def cloth_filter(type: typing.Union[int, str] = 'GRAVITY',
+def cloth_filter(type: typing.Union[str, int] = 'GRAVITY',
                  strength: float = 1.0,
-                 force_axis: typing.Union[typing.Set[int], typing.Set[str]] = {
+                 force_axis: typing.Union[typing.Set[str], typing.Set[int]] = {
                      'X', 'Y', 'Z'
                  },
-                 orientation: typing.Union[int, str] = 'LOCAL',
+                 orientation: typing.Union[str, int] = 'LOCAL',
                  cloth_mass: float = 1.0,
                  cloth_damping: float = 0.0,
                  use_face_sets: bool = False,
@@ -34,13 +34,13 @@ def cloth_filter(type: typing.Union[int, str] = 'GRAVITY',
     ''' Applies a cloth simulation deformation to the entire mesh
 
     :param type: Filter Type, Operation that is going to be applied to the mesh * GRAVITY Gravity -- Applies gravity to the simulation. * INFLATE Inflate -- Inflates the cloth. * EXPAND Expand -- Expands the cloth's dimensions. * PINCH Pinch -- Pulls the cloth to the cursor's start position. * SCALE Scale -- Scales the mesh as a soft body using the origin of the object as scale.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
     :type strength: float
     :param force_axis: Force Axis, Apply the force in the selected axis * X X -- Apply force in the X axis. * Y Y -- Apply force in the Y axis. * Z Z -- Apply force in the Z axis.
-    :type force_axis: typing.Union[typing.Set[int], typing.Set[str]]
+    :type force_axis: typing.Union[typing.Set[str], typing.Set[int]]
     :param orientation: Orientation, Orientation of the axis to limit the filter force * LOCAL Local -- Use the local axis to limit the force and set the gravity direction. * WORLD World -- Use the global axis to limit the force and set the gravity direction. * VIEW View -- Use the view axis to limit the force and set the gravity direction.
-    :type orientation: typing.Union[int, str]
+    :type orientation: typing.Union[str, int]
     :param cloth_mass: Cloth Mass, Mass of each simulation particle
     :type cloth_mass: float
     :param cloth_damping: Cloth Damping, How much the applied forces are propagated through the cloth
@@ -54,13 +54,13 @@ def cloth_filter(type: typing.Union[int, str] = 'GRAVITY',
     pass
 
 
-def color_filter(type: typing.Union[int, str] = 'HUE',
+def color_filter(type: typing.Union[str, int] = 'HUE',
                  strength: float = 1.0,
                  fill_color: typing.List[float] = (0.0, 0.0, 0.0)):
     ''' Applies a filter to modify the current sculpt vertex colors
 
     :param type: Filter Type * FILL Fill -- Fill with a specific color. * HUE Hue -- Change hue. * SATURATION Saturation -- Change saturation. * VALUE Value -- Change value. * BRIGHTNESS Brightness -- Change brightness. * CONTRAST Contrast -- Change contrast. * SMOOTH Smooth -- Smooth colors. * RED Red -- Change red channel. * GREEN Green -- Change green channel. * BLUE Blue -- Change blue channel.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
     :type strength: float
     :param fill_color: Fill Color
@@ -104,8 +104,8 @@ def dyntopo_detail_size_edit():
     pass
 
 
-def expand(target: typing.Union[int, str] = 'MASK',
-           falloff_type: typing.Union[int, str] = 'GEODESIC',
+def expand(target: typing.Union[str, int] = 'MASK',
+           falloff_type: typing.Union[str, int] = 'GEODESIC',
            invert: bool = False,
            use_mask_preserve: bool = False,
            use_falloff_gradient: bool = False,
@@ -115,9 +115,9 @@ def expand(target: typing.Union[int, str] = 'MASK',
     ''' Generic sculpt expand operator
 
     :param target: Data Target, Data that is going to be modified in the expand operation
-    :type target: typing.Union[int, str]
+    :type target: typing.Union[str, int]
     :param falloff_type: Falloff Type, Initial falloff of the expand operation
-    :type falloff_type: typing.Union[int, str]
+    :type falloff_type: typing.Union[str, int]
     :param invert: Invert, Invert the expand active elements
     :type invert: bool
     :param use_mask_preserve: Preserve Previous, Preserve the previous state of the target data
@@ -163,22 +163,22 @@ def face_set_box_gesture(xmin: int = 0,
     pass
 
 
-def face_set_change_visibility(mode: typing.Union[int, str] = 'TOGGLE'):
+def face_set_change_visibility(mode: typing.Union[str, int] = 'TOGGLE'):
     ''' Change the visibility of the Face Sets of the sculpt
 
     :param mode: Mode * TOGGLE Toggle Visibility -- Hide all Face Sets except for the active one. * SHOW_ACTIVE Show Active Face Set -- Show Active Face Set. * HIDE_ACTIVE Hide Active Face Sets -- Hide Active Face Sets. * INVERT Invert Face Set Visibility -- Invert Face Set Visibility. * SHOW_ALL Show All Face Sets -- Show All Face Sets.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def face_set_edit(mode: typing.Union[int, str] = 'GROW',
+def face_set_edit(mode: typing.Union[str, int] = 'GROW',
                   modify_hidden: bool = True):
     ''' Edits the current active Face Set
 
     :param mode: Mode * GROW Grow Face Set -- Grows the Face Sets boundary by one face based on mesh topology. * SHRINK Shrink Face Set -- Shrinks the Face Sets boundary by one face based on mesh topology. * DELETE_GEOMETRY Delete Geometry -- Deletes the faces that are assigned to the Face Set. * FAIR_POSITIONS Fair Positions -- Creates a smooth as possible geometry patch from the Face Set minimizing changes in vertex positions. * FAIR_TANGENCY Fair Tangency -- Creates a smooth as possible geometry patch from the Face Set minimizing changes in vertex tangents.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param modify_hidden: Modify Hidden, Apply the edit operation to hidden Face Sets
     :type modify_hidden: bool
     '''
@@ -204,22 +204,22 @@ def face_set_lasso_gesture(path: typing.Union[
     pass
 
 
-def face_sets_create(mode: typing.Union[int, str] = 'MASKED'):
+def face_sets_create(mode: typing.Union[str, int] = 'MASKED'):
     ''' Create a new Face Set
 
     :param mode: Mode * MASKED Face Set from Masked -- Create a new Face Set from the masked faces. * VISIBLE Face Set from Visible -- Create a new Face Set from the visible vertices. * ALL Face Set Full Mesh -- Create an unique Face Set with all faces in the sculpt. * SELECTION Face Set from Edit Mode Selection -- Create an Face Set corresponding to the Edit Mode face selection.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def face_sets_init(mode: typing.Union[int, str] = 'LOOSE_PARTS',
+def face_sets_init(mode: typing.Union[str, int] = 'LOOSE_PARTS',
                    threshold: float = 0.5):
     ''' Initializes all Face Sets in the mesh
 
     :param mode: Mode * LOOSE_PARTS Face Sets from Loose Parts -- Create a Face Set per loose part in the mesh. * MATERIALS Face Sets from Material Slots -- Create a Face Set per Material Slot. * NORMALS Face Sets from Mesh Normals -- Create Face Sets for Faces that have similar normal. * UV_SEAMS Face Sets from UV Seams -- Create Face Sets using UV Seams as boundaries. * CREASES Face Sets from Edge Creases -- Create Face Sets using Edge Creases as boundaries. * BEVEL_WEIGHT Face Sets from Bevel Weight -- Create Face Sets using Bevel Weights as boundaries. * SHARP_EDGES Face Sets from Sharp Edges -- Create Face Sets using Sharp Edges as boundaries. * FACE_MAPS Face Sets from Face Maps -- Create a Face Set per Face Map. * FACE_SET_BOUNDARIES Face Sets from Face Set Boundaries -- Create a Face Set per isolated Face Set.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param threshold: Threshold, Minimum value to consider a certain attribute a boundary when creating the Face Sets
     :type threshold: float
     '''
@@ -296,13 +296,13 @@ def mask_expand(invert: bool = True,
     pass
 
 
-def mask_filter(filter_type: typing.Union[int, str] = 'SMOOTH',
+def mask_filter(filter_type: typing.Union[str, int] = 'SMOOTH',
                 iterations: int = 1,
                 auto_iteration_count: bool = False):
     ''' Applies a filter to modify the current mask
 
     :param filter_type: Type, Filter that is going to be applied to the mask * SMOOTH Smooth Mask -- Smooth mask. * SHARPEN Sharpen Mask -- Sharpen mask. * GROW Grow Mask -- Grow mask. * SHRINK Shrink Mask -- Shrink mask. * CONTRAST_INCREASE Increase Contrast -- Increase the contrast of the paint mask. * CONTRAST_DECREASE Decrease Contrast -- Decrease the contrast of the paint mask.
-    :type filter_type: typing.Union[int, str]
+    :type filter_type: typing.Union[str, int]
     :param iterations: Iterations, Number of times that the filter is going to be applied
     :type iterations: int
     :param auto_iteration_count: Auto Iteration Count, Use a automatic number of iterations based on the number of vertices of the sculpt
@@ -312,22 +312,22 @@ def mask_filter(filter_type: typing.Union[int, str] = 'SMOOTH',
     pass
 
 
-def mask_init(mode: typing.Union[int, str] = 'RANDOM_PER_VERTEX'):
+def mask_init(mode: typing.Union[str, int] = 'RANDOM_PER_VERTEX'):
     ''' Creates a new mask for the entire mesh
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def mesh_filter(type: typing.Union[int, str] = 'INFLATE',
+def mesh_filter(type: typing.Union[str, int] = 'INFLATE',
                 strength: float = 1.0,
-                deform_axis: typing.Union[typing.Set[int], typing.Set[str]] = {
+                deform_axis: typing.Union[typing.Set[str], typing.Set[int]] = {
                     'X', 'Y', 'Z'
                 },
-                orientation: typing.Union[int, str] = 'LOCAL',
+                orientation: typing.Union[str, int] = 'LOCAL',
                 surface_smooth_shape_preservation: float = 0.5,
                 surface_smooth_current_vertex: float = 0.5,
                 sharpen_smooth_ratio: float = 0.35,
@@ -336,13 +336,13 @@ def mesh_filter(type: typing.Union[int, str] = 'INFLATE',
     ''' Applies a filter to modify the current mesh
 
     :param type: Filter Type, Operation that is going to be applied to the mesh * SMOOTH Smooth -- Smooth mesh. * SCALE Scale -- Scale mesh. * INFLATE Inflate -- Inflate mesh. * SPHERE Sphere -- Morph into sphere. * RANDOM Random -- Randomize vertex positions. * RELAX Relax -- Relax mesh. * RELAX_FACE_SETS Relax Face Sets -- Smooth the edges of all the Face Sets. * SURFACE_SMOOTH Surface Smooth -- Smooth the surface of the mesh, preserving the volume. * SHARPEN Sharpen -- Sharpen the cavities of the mesh. * ENHANCE_DETAILS Enhance Details -- Enhance the high frequency surface detail. * ERASE_DISCPLACEMENT Erase Displacement -- Deletes the displacement of the Multires Modifier.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param strength: Strength, Filter strength
     :type strength: float
     :param deform_axis: Deform Axis, Apply the deformation in the selected axis * X X -- Deform in the X axis. * Y Y -- Deform in the Y axis. * Z Z -- Deform in the Z axis.
-    :type deform_axis: typing.Union[typing.Set[int], typing.Set[str]]
+    :type deform_axis: typing.Union[typing.Set[str], typing.Set[int]]
     :param orientation: Orientation, Orientation of the axis to limit the filter displacement * LOCAL Local -- Use the local axis to limit the displacement. * WORLD World -- Use the global axis to limit the displacement. * VIEW View -- Use the view axis to limit the displacement.
-    :type orientation: typing.Union[int, str]
+    :type orientation: typing.Union[str, int]
     :param surface_smooth_shape_preservation: Shape Preservation, How much of the original shape is preserved when smoothing
     :type surface_smooth_shape_preservation: float
     :param surface_smooth_current_vertex: Per Vertex Displacement, How much the position of each individual vertex influences the final result
@@ -406,13 +406,13 @@ def sample_color():
 
 
 def sample_detail_size(location: typing.List[int] = (0, 0),
-                       mode: typing.Union[int, str] = 'DYNTOPO'):
+                       mode: typing.Union[str, int] = 'DYNTOPO'):
     ''' Sample the mesh detail on clicked point
 
     :param location: Location, Screen coordinates of sampling
     :type location: typing.List[int]
     :param mode: Detail Mode, Target sculpting workflow that is going to use the sampled size * DYNTOPO Dyntopo -- Sample dyntopo detail. * VOXEL Voxel -- Sample mesh voxel size.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -442,13 +442,13 @@ def set_persistent_base():
     pass
 
 
-def set_pivot_position(mode: typing.Union[int, str] = 'UNMASKED',
+def set_pivot_position(mode: typing.Union[str, int] = 'UNMASKED',
                        mouse_x: float = 0.0,
                        mouse_y: float = 0.0):
     ''' Sets the sculpt transform pivot position
 
     :param mode: Mode * ORIGIN Origin -- Sets the pivot to the origin of the sculpt. * UNMASKED Unmasked -- Sets the pivot position to the average position of the unmasked vertices. * BORDER Mask Border -- Sets the pivot position to the center of the border of the mask. * ACTIVE Active Vertex -- Sets the pivot position to the active vertex position. * SURFACE Surface -- Sets the pivot position to the surface under the cursor.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param mouse_x: Mouse Position X, Position of the mouse used for "Surface" mode
     :type mouse_x: float
     :param mouse_y: Mouse Position Y, Position of the mouse used for "Surface" mode
@@ -475,9 +475,9 @@ def trim_box_gesture(xmin: int = 0,
                      wait_for_input: bool = True,
                      use_front_faces_only: bool = False,
                      use_limit_to_segment: bool = False,
-                     trim_mode: typing.Union[int, str] = 'DIFFERENCE',
+                     trim_mode: typing.Union[str, int] = 'DIFFERENCE',
                      use_cursor_depth: bool = False,
-                     trim_orientation: typing.Union[int, str] = 'VIEW'):
+                     trim_orientation: typing.Union[str, int] = 'VIEW'):
     ''' Trims the mesh within the box as you move the brush
 
     :param xmin: X Min
@@ -495,11 +495,11 @@ def trim_box_gesture(xmin: int = 0,
     :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
     :type use_limit_to_segment: bool
     :param trim_mode: Trim Mode * DIFFERENCE Difference -- Use a difference boolean operation. * UNION Union -- Use a union boolean operation. * JOIN Join -- Join the new mesh as separate geometry, without performing any boolean operation.
-    :type trim_mode: typing.Union[int, str]
+    :type trim_mode: typing.Union[str, int]
     :param use_cursor_depth: Use Cursor for Depth, Use cursor location and radius for the dimensions and position of the trimming shape
     :type use_cursor_depth: bool
     :param trim_orientation: Shape Orientation * VIEW View -- Use the view to orientate the trimming shape. * SURFACE Surface -- Use the surface normal to orientate the trimming shape.
-    :type trim_orientation: typing.Union[int, str]
+    :type trim_orientation: typing.Union[str, int]
     '''
 
     pass
@@ -510,9 +510,9 @@ def trim_lasso_gesture(path: typing.Union[
         List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                        use_front_faces_only: bool = False,
                        use_limit_to_segment: bool = False,
-                       trim_mode: typing.Union[int, str] = 'DIFFERENCE',
+                       trim_mode: typing.Union[str, int] = 'DIFFERENCE',
                        use_cursor_depth: bool = False,
-                       trim_orientation: typing.Union[int, str] = 'VIEW'):
+                       trim_orientation: typing.Union[str, int] = 'VIEW'):
     ''' Trims the mesh within the lasso as you move the brush
 
     :param path: Path
@@ -522,21 +522,21 @@ def trim_lasso_gesture(path: typing.Union[
     :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
     :type use_limit_to_segment: bool
     :param trim_mode: Trim Mode * DIFFERENCE Difference -- Use a difference boolean operation. * UNION Union -- Use a union boolean operation. * JOIN Join -- Join the new mesh as separate geometry, without performing any boolean operation.
-    :type trim_mode: typing.Union[int, str]
+    :type trim_mode: typing.Union[str, int]
     :param use_cursor_depth: Use Cursor for Depth, Use cursor location and radius for the dimensions and position of the trimming shape
     :type use_cursor_depth: bool
     :param trim_orientation: Shape Orientation * VIEW View -- Use the view to orientate the trimming shape. * SURFACE Surface -- Use the surface normal to orientate the trimming shape.
-    :type trim_orientation: typing.Union[int, str]
+    :type trim_orientation: typing.Union[str, int]
     '''
 
     pass
 
 
-def uv_sculpt_stroke(mode: typing.Union[int, str] = 'NORMAL'):
+def uv_sculpt_stroke(mode: typing.Union[str, int] = 'NORMAL'):
     ''' Sculpt UVs using a brush
 
     :param mode: Mode, Stroke Mode * NORMAL Regular -- Apply brush normally. * INVERT Invert -- Invert action of brush for duration of stroke. * RELAX Relax -- Switch brush to relax mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
