@@ -3,7 +3,7 @@ import typing
 
 
 def new():
-    ''' Add a new world
+    ''' Create a new world Data-Block
 
     '''
 
