@@ -2,18 +2,15 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
 
-
-def bake_action(obj: 'bpy.types.Object', *,
-                action: typing.Optional['bpy.types.Action'], frames: int,
-                **kwargs) -> 'bpy.types.Action':
+def bake_action(obj: 'bpy.types.Object', *, action: 'bpy.types.Action',
+                frames: int, **kwargs) -> 'bpy.types.Action':
     ''' 
 
     :param obj: Object to bake.
     :type obj: 'bpy.types.Object'
     :param action: An action to bake the data into, or None for a new action to be created.
-    :type action: typing.Optional['bpy.types.Action']
+    :type action: 'bpy.types.Action'
     :param frames: Frames to bake.
     :type frames: int
     :rtype: 'bpy.types.Action'
@@ -25,7 +22,7 @@ def bake_action(obj: 'bpy.types.Object', *,
 
 def bake_action_iter(obj: 'bpy.types.Object',
                      *,
-                     action: typing.Optional['bpy.types.Action'],
+                     action: 'bpy.types.Action',
                      only_selected: bool = False,
                      do_pose: bool = True,
                      do_object: bool = True,
@@ -38,7 +35,7 @@ def bake_action_iter(obj: 'bpy.types.Object',
     :param obj: Object to bake.
     :type obj: 'bpy.types.Object'
     :param action: An action to bake the data into, or None for a new action to be created.
-    :type action: typing.Optional['bpy.types.Action']
+    :type action: 'bpy.types.Action'
     :param only_selected: Only bake selected bones.
     :type only_selected: bool
     :param do_pose: Bake pose channels.
@@ -61,13 +58,13 @@ def bake_action_iter(obj: 'bpy.types.Object',
 
 
 def bake_action_objects(object_action_pairs, *, frames: int,
-                        **kwargs) -> typing.Sequence['bpy.types.Action']:
-    ''' A version of :func:`bake_action_objects_iter` that takes frames and returns the output.
+                        **kwargs) -> 'bpy.types.Action':
+    ''' A version of :func: bake_action_objects_iter that takes frames and returns the output.
 
     :param frames: Frames to bake.
     :type frames: int
-    :rtype: typing.Sequence['bpy.types.Action']
-    :return: A sequence of Action or None types (aligned with `object_action_pairs`)
+    :rtype: 'bpy.types.Action'
+    :return: A sequence of Action or None types (aligned with object_action_pairs )
     '''
 
     pass
