@@ -2,15 +2,13 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 def load_image(imagepath,
                dirname: str = '',
                place_holder: bool = False,
                recursive: bool = False,
                ncase_cmp: bool = True,
-               convert_callback: typing.Any = None,
+               convert_callback=None,
                verbose=False,
                relpath: str = None,
                check_existing: bool = False,
@@ -28,12 +26,11 @@ def load_image(imagepath,
     :param ncase_cmp: on non windows systems, find the correct case for the file.
     :type ncase_cmp: bool
     :param convert_callback: a function that takes an existing path and returns a new one. Use this when loading image formats blender may not support, the CONVERT_CALLBACK can take the path for a GIF (for example), convert it to a PNG and return the PNG's path. For formats blender can read, simply return the path that is given.
-    :type convert_callback: typing.Any
     :param relpath: If not None, make the file relative to this path.
     :type relpath: str
     :param check_existing: If true, returns already loaded image datablock if possible (based on file path).
     :type check_existing: bool
-    :param force_reload: If true, force reloading of image (only useful when `check_existing` is also enabled).
+    :param force_reload: If true, force reloading of image (only useful when check_existing is also enabled).
     :type force_reload: bool
     :rtype: 'bpy.types.Image'
     :return: an image or None
